@@ -32,18 +32,14 @@ def main(db_engine='sqlite3'):
     global_settings.STATIC_ROOT = global_settings.MEDIA_ROOT
     
     global_settings.SECRET_KEY = '334ebe58-a77d-4321-9d01-a7d2cb8d3eea'
-    global_settings.COVERAGE_REPORT_HTML_OUTPUT_DIR = os.path.join(BASE_PATH, '.coverage')
-    global_settings.COVERAGE_USE_STDOUT = True
-    global_settings.COVERAGE_PATH_EXCLUDES = ['.hg', 'templates', 'tests', 'sql', '__pycache__']
-    
-    if os.environ.get('COVERAGE', None):
-        from django_coverage import coverage_runner
-        test_runner = coverage_runner.CoverageRunner
-    else:
-        from django.test.utils import get_runner
-        test_runner = get_runner(global_settings)
+    from django.test.utils import get_runner
+    test_runner = get_runner(global_settings)
 
     test_runner = test_runner()
+    
+    if getattr(django, 'setup', None):
+        django.setup()
+    
     failures = test_runner.run_tests(['jsonfield'])
     
     sys.exit(failures)
